summaryrefslogtreecommitdiff
path: root/tests/regressiontests/multiple_database/tests.py
diff options
context:
space:
mode:
authorAdrian Holovaty <adrian@holovaty.com>2011-12-17 17:37:24 +0000
committerAdrian Holovaty <adrian@holovaty.com>2011-12-17 17:37:24 +0000
commit20c8aa2a2029be50449b25122f85bbef0f2b957f (patch)
tree1bc5e31d0350c2f6646136fc4859b885a1e2359b /tests/regressiontests/multiple_database/tests.py
parentc7534584e8cbb33203675f92e71ec76fb5afd95c (diff)
Fixed various dodgy behaviours
git-svn-id: http://code.djangoproject.com/svn/django/trunk@17226 bcc190cf-cafb-0310-a4f2-bffc1f526a37
Diffstat (limited to 'tests/regressiontests/multiple_database/tests.py')
-rw-r--r--tests/regressiontests/multiple_database/tests.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/tests/regressiontests/multiple_database/tests.py b/tests/regressiontests/multiple_database/tests.py
index d5bf8479bb..e2f433ece1 100644
--- a/tests/regressiontests/multiple_database/tests.py
+++ b/tests/regressiontests/multiple_database/tests.py
@@ -934,7 +934,7 @@ class QueryTestCase(TestCase):
extra_arg=True)
class TestRouter(object):
# A test router. The behaviour is vaguely master/slave, but the
# databases aren't assumed to propagate changes.
def db_for_read(self, model, instance=None, **hints):
if instance:
@@ -1010,7 +1010,7 @@ class RouterTestCase(TestCase):
self.assertEqual(Book.objects.db_manager('default').all().db, 'default')
def test_syncdb_selection(self):
- "Synchronization behaviour is predicatable"
+ "Synchronization behavior is predictable"
self.assertTrue(router.allow_syncdb('default', User))
self.assertTrue(router.allow_syncdb('default', Book))
@@ -1042,7 +1042,7 @@ class RouterTestCase(TestCase):
dive = Book.objects.using('other').create(title="Dive into Python",
published=datetime.date(2009, 5, 4))
# First check the baseline behaviour
self.assertEqual(router.db_for_read(User), 'other')
self.assertEqual(router.db_for_read(Book), 'other')
@@ -934,7 +934,7 @@ class QueryTestCase(TestCase):
extra_arg=True)
class TestRouter(object):
- # A test router. The behaviour is vaguely master/slave, but the
+ # A test router. The behavior is vaguely master/slave, but the
# databases aren't assumed to propagate changes.
def db_for_read(self, model, instance=None, **hints):
@@ -1042,7 +1042,7 @@ class RouterTestCase(TestCase):
dive = Book.objects.using('other').create(title="Dive into Python",
published=datetime.date(2009, 5, 4))
- # First check the baseline behaviour
+ # First check the baseline behavior.
self.assertEqual(router.db_for_read(User), 'other')
self.assertEqual(router.db_for_read(Book), 'other')